@@ -492,9 +492,9 @@ impl StateHub {
             .await?;
 
         self.inform(format!(
-            "Registering {} cluster {} in {}",
+            "Registering {:#} cluster {} in {}",
             provider,
-            cluster.show(),
+            cluster.name,
             locations.show()
         ));
         if let Some(ref states) = states {
